/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.odfweb.course;

import org.apache.avalon.framework.context.Context;
import org.apache.avalon.framework.context.ContextException;
import org.apache.avalon.framework.context.Contextualizable;
import org.apache.cocoon.components.ContextHelper;
import org.apache.cocoon.environment.Request;

import org.ametys.cms.repository.Content;
import org.ametys.core.util.URIUtils;
import org.ametys.odf.course.ShareableCourseStatusHelper;
import org.ametys.web.WebHelper;

/**
 * Helper for web shareable course status
 */
public class WebShareableCourseStatusHelper extends ShareableCourseStatusHelper implements Contextualizable
{
    private Context _context;
    
    public void contextualize(Context context) throws ContextException
    {
        _context = context;
    }
    
    @Override
    protected String _getContentUri(Content content)
    {
        String siteName = _getSiteName(content);
        return _getRequestUri() + "/" + siteName + "/index.html?uitool=uitool-content,id:%27" + URIUtils.encodeParameter(content.getId()) + "%27";
    }
    
    /**
     * Get the site name
     * @param content the content
     * @return the site name
     */
    protected String _getSiteName(Content content)
    {
        Request request = ContextHelper.getRequest(_context);
        return WebHelper.getSiteName(request, content);
    }
}
